@@ -1,9 +1,9 @@
 package Strehler::Element;
-$Strehler::Element::VERSION = '1.6.1';
+$Strehler::Element::VERSION = '1.6.2';
 use strict;
 use Carp 'carp';
 use Moo;
-use Dancer2 0.154000;
+use Dancer2 0.160000;
 use Dancer2::Plugin::DBIC;
 use Strehler::Meta::Tag;
 use Strehler::Meta::Category;
@@ -868,6 +868,14 @@ sub get_list
     return {'to_view' => \@to_view, 'last_page' => $last_page};
 }
 
+sub has_tag
+{
+    my $self = shift;
+    my $tag = shift;
+    return 0 if(! $self->categorized());
+    return Strehler::Meta::Tag->exists_tag($self->get_attr('id'), $self->item_type(), $tag);
+}
+
 sub search_box
 {
     my $self = shift;
@@ -1017,6 +1025,10 @@ sub save_form
     {
         $el_data->{'published'} = 1;
     }
+    if($form->param_value('strehl-action') eq 'submit-publish')
+    {
+        $el_data->{'published'} = 1;
+    }
     if($id)
     {
         $el_row = $self->get_schema()->resultset($self->ORMObj())->find($id);
