@@ -1,8 +1,8 @@
 package Strehler::Meta::Tag;
-$Strehler::Meta::Tag::VERSION = '1.6.1';
+$Strehler::Meta::Tag::VERSION = '1.6.2';
 use strict;
 use Moo;
-use Dancer2 0.154000;
+use Dancer2 0.160000;
 use Dancer2::Plugin::DBIC;
 use Strehler::Meta::Category;
 
@@ -168,6 +168,15 @@ sub clean_configured_tags
     my $category = shift;
     $self->get_schema()->resultset('ConfiguredTag')->search({ category_id => $category })->delete_all();
 }
+sub exists_tag
+{
+    my $self = shift;
+    my $id = shift;
+    my $entity = shift;
+    my $tag = shift;
+    my $many = $self->get_schema()->resultset('Tag')->search({tag => $tag, item_id => $id, item_type => $entity})->count();
+    return $many > 0;
+}
 
 =encoding utf8
 
